==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/da-DK/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'En bruger har accepteret et emne',
    'acceptance_asset_declined' => 'En bruger har afvist et emne',
    'a_user_canceled' => 'En bruger har annulleret en vareforespørgsel på hjemmesiden',
    'a_user_requested' => 'En bruger har anmodet om et emne på hjemmesiden',
    'accessory_name' => 'Tilbehør Navn:',
    'additional_notes' => 'Yderligere bemærkninger:',
    'admin_has_created' => 'En administrator har oprettet en konto til dig på webstedet:.',
    'asset' => 'aktiv:',
    'asset_name' => 'Aktivnavn:',
    'asset_requested' => 'Aktiver bedt om',
    'asset_tag' => 'Inventarnummer',
    'assigned_to' => 'Tildelt',
    'best_regards' => 'Med venlig hilsen,',
    'canceled' => 'annulleret:',
    'checkin_date' => 'Checkin dato:',
    'checkout_date' => 'Checkout dato:',
    'click_to_confirm' => 'Venligst klik på følgende link for at bekræfte din: web-konto:',
    'click_on_the_link_accessory' => 'Venligst klik på linket nederst for at bekræfte, at du har modtaget tilbehør.',
    'click_on_the_link_asset' => 'Klik venligst på linket nederst for at bekræfte, at du har modtaget aktivet.',
    'Confirm_Asset_Checkin' => 'Asset checkin bekræftelse',
    'Confirm_Accessory_Checkin' => 'Tilbehør checkin bekræftelse',
    'Confirm_accessory_delivery' => 'Tilbehør leveringsbekræftelse',
    'Confirm_license_delivery' => 'Licens leveringsbekræftelse',
    'Confirm_asset_delivery' => 'Asset leveringsbekræftelse',
    'Confirm_consumable_delivery' => 'Forbrugsvare leveringsbekræftelse',
    'current_QTY' => 'Nuværende QTY',
    'Days' => 'Dage',
    'days' => 'Dage',
    'expecting_checkin_date' => 'Forventet Checkin Date:',
    'expires' => 'udløber',
    'Expiring_Assets_Report' => 'Udløbsaktiver Rapport.',
    'Expiring_Licenses_Report' => 'Udløber Licenser Rapport.',
    'hello' => 'Hej',
    'hi' => 'Hej',
    'i_have_read' => 'Jeg har læst og accepterer vilkårene for brug og har modtaget denne vare.',
    'item' => 'Vare:',
    'Item_Request_Canceled' => 'Elementforespørgsel annulleret',
    'Item_Requested' => 'Vareanmodning',
    'link_to_update_password' => 'Venligst klik på følgende link for at opdatere din: webadgangskode:',
    'login_first_admin' => 'Log ind på din nye Snipe-IT-installation ved hjælp af nedenstående referencer:',
    'login' => 'Log på:',
    'Low_Inventory_Report' => 'Lav lagerrapport',
    'inventory_report' => 'Lagerrapport',
    'min_QTY' => 'Min QTY',
    'name' => 'Navn',
    'new_item_checked' => 'En ny vare er blevet tjekket ud under dit navn, detaljerne er nedenfor.',
    'password' => 'Adgangskode:',
    'password_reset' => 'Nulstil kodeord',

    'read_the_terms' => 'Læs venligst brugsbetingelserne nedenfor.',
    'read_the_terms_and_click' => 'Læs venligst brugsbetingelserne nedenfor, og klik på linket nederst for at bekræfte, at du læser og accepterer vilkårene for brug og har modtaget aktivet.',
    'requested' => 'Anmodede om:',
    'reset_link' => 'Din Password Reset Link',
    'reset_password' => 'Klik her for at nulstille adgangskoden:',
    'serial' => 'Seriel',
    'supplier' => 'Leverandør',
    'tag' => 'Mærkat',
    'test_email' => 'Test E-mail fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT Asset Management System. Hvis du fik dette, virker mailen :)',
    'the_following_item' => 'Følgende vare er blevet kontrolleret i:',
    'low_inventory_alert' => 'Der er :count enhed som er under minimum lagertal eller som snart vil være det.|Der er :count enheder som er under minimum lagertal eller som snart vil være det.',
    'assets_warrantee_alert' => 'Der er :count aktiv hvor garantien udløber indenfor de næste :threshold dage.|Der er :count aktiver hvor garantien udløber indenfor de næste :threshold dage.',
    'license_expiring_alert' => 'Der er :count licens(er) der udløber indenfor den/de næste :threshold dag(e).',
    'to_reset' => 'Nulstille din :web-adgangskode, udfylde denne formular:',
    'type' => 'Type',
    'upcoming-audits' => 'Der er :count asset, som skal tilses inden :threshold dage. |Der er :count assets, som skal tilses inden :threshold dage.',
    'user' => 'Bruger',
    'username' => 'Brugernavn',
    'welcome' => 'Velkommen :navn',
    'welcome_to' => 'Velkommen til :web!',
    'your_credentials' => 'Dine Snipe-IT Legitimationsoplysninger',
    'Accessory_Checkin_Notification' => 'Tilbehør tjekket ind',
    'Asset_Checkin_Notification' => 'Asset tjekket ind',
    'Asset_Checkout_Notification' => 'Aktiv tjekket ud',
    'License_Checkin_Notification' => 'Licens tjekket ind',
    'Expected_Checkin_Report' => 'Forventet asset checkin rapport',
    'Expected_Checkin_Notification' => 'Påmindelse: :name checkin deadline nærmer sig',
    'Expected_Checkin_Date' => 'Et asset tjekket ud til dig skal tjekkes tilbage den :date',
    'your_assets' => 'Se dine assets',
    'rights_reserved' => 'Alle rettigheder forbeholdt.',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/da-DK/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tilbehør tjekket ind',
    'Accessory_Checkout_Notification' => 'Tilbehør tjekket ud',
    'Asset_Checkin_Notification' => 'Asset tjekket ind',
    'Asset_Checkout_Notification' => 'Aktiv tjekket ud',
    'Confirm_Accessory_Checkin' => 'Tilbehør checkin bekræftelse',
    'Confirm_Asset_Checkin' => 'Asset checkin bekræftelse',
    'Confirm_accessory_delivery' => 'Tilbehør leveringsbekræftelse',
    'Confirm_asset_delivery' => 'Asset leveringsbekræftelse',
    'Confirm_consumable_delivery' => 'Forbrugsvare leveringsbekræftelse',
    'Confirm_license_delivery' => 'Licens leveringsbekræftelse',
    'Consumable_checkout_notification' => 'Forbrugsstoffer tjekket ud',
    'Days' => 'Dage',
    'Expected_Checkin_Date' => 'Et asset tjekket ud til dig skal tjekkes tilbage den :date',
    'Expected_Checkin_Notification' => 'Påmindelse: :name checkin deadline nærmer sig',
    'Expected_Checkin_Report' => 'Forventet asset checkin rapport',
    'Expiring_Assets_Report' => 'Udløbsaktiver Rapport.',
    'Expiring_Licenses_Report' => 'Udløber Licenser Rapport.',
    'Item_Request_Canceled' => 'Elementforespørgsel annulleret',
    'Item_Requested' => 'Vareanmodning',
    'License_Checkin_Notification' => 'Licens tjekket ind',
    'License_Checkout_Notification' => 'Licens tjekket ud',
    'Low_Inventory_Report' => 'Lav lagerrapport',
    'a_user_canceled' => 'En bruger har annulleret en vareforespørgsel på hjemmesiden',
    'a_user_requested' => 'En bruger har anmodet om et emne på hjemmesiden',
    'acceptance_asset_accepted' => 'En bruger har accepteret et emne',
    'acceptance_asset_declined' => 'En bruger har afvist et emne',
    'accessory_name' => 'Tilbehør Navn',
    'additional_notes' => 'Yderligere bemærkninger',
    'admin_has_created' => 'En administrator har oprettet en konto til dig på webstedet:.',
    'asset' => 'Asset',
    'asset_name' => 'Aktivnavn',
    'asset_requested' => 'Aktiver bedt om',
    'asset_tag' => 'Inventarnummer',
    'assets_warrantee_alert' => 'Der er :count aktiv hvor garantien udløber indenfor de næste :threshold dage.|Der er :count aktiver hvor garantien udløber indenfor de næste :threshold dage.',
    'assigned_to' => 'Tildelt',
    'best_regards' => 'Med venlig hilsen,',
    'canceled' => 'annulleret',
    'checkin_date' => 'Tjekket Ind Dato',
    'checkout_date' => 'Checkout dato',
    'checkedout_from' => 'Tjekket ud fra',
    'checkedin_from'  => 'Tjekket ind fra',
    'checked_into' => 'Tjekket ind',
    'click_on_the_link_accessory' => 'Venligst klik på linket nederst for at bekræfte, at du har modtaget tilbehør.',
    'click_on_the_link_asset' => 'Klik venligst på linket nederst for at bekræfte, at du har modtaget aktivet.',
    'click_to_confirm' => 'Venligst klik på følgende link for at bekræfte din: web-konto:',
    'current_QTY' => 'Nuværende QTY',
    'days' => 'Dage',
    'expecting_checkin_date' => 'Forventet indtjekningsdato',
    'expires' => 'udløber',
    'hello' => 'Hej',
    'hi' => 'Hej',
    'i_have_read' => 'Jeg har læst og accepterer vilkårene for brug og har modtaget denne vare.',
    'inventory_report' => 'Lagerrapport',
    'item' => 'Emne',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Der er :count licens(er) der udløber indenfor den/de næste :threshold dag(e).',
    'link_to_update_password' => 'Venligst klik på følgende link for at opdatere din: webadgangskode:',
    'login' => 'Log på:',
    'login_first_admin' => 'Log ind på din nye Snipe-IT-installation ved hjælp af nedenstående referencer:',
    'low_inventory_alert' => 'Der er :count enhed som er under minimum lagertal eller som snart vil være det.|Der er :count enheder som er under minimum lagertal eller som snart vil være det.',
    'min_QTY' => 'Min QTY',
    'name' => 'Navn',
    'new_item_checked' => 'En ny vare er blevet tjekket ud under dit navn, detaljerne er nedenfor.',
    'notes' => 'Noter',
    'password' => 'Adgangskode',
    'password_reset' => 'Nulstil kodeord',
    'read_the_terms' => 'Læs venligst brugsbetingelserne nedenfor.',
    'read_the_terms_and_click' => 'Læs venligst vilkårene for brug nedenfor, og klik på linket nederst for at bekræfte, at du læser og accepterer vilkårene for brug, og har modtaget aktivet.',
    'requested' => 'Anmodet',
    'reset_link' => 'Din Password Reset Link',
    'reset_password' => 'Klik her for at nulstille adgangskoden:',
    'rights_reserved' => 'Alle rettigheder forbeholdt.',
    'serial' => 'Seriel',
    'snipe_webhook_test' => 'Snipe-IT-Integrationstest',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Resumé',
    'supplier' => 'Leverandør',
    'tag' => 'Mærkat',
    'test_email' => 'Test E-mail fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT Asset Management System. Hvis du fik dette, virker mailen :)',
    'the_following_item' => 'Følgende vare er blevet kontrolleret i:',
    'to_reset' => 'Nulstille din :web-adgangskode, udfylde denne formular:',
    'type' => 'Type',
    'upcoming-audits' => 'Der er :count asset, som skal tilses inden :threshold dage. |Der er :count assets, som skal tilses inden :threshold dage.',
    'user' => 'Bruger',
    'username' => 'Brugernavn',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Velkommen :navn',
    'welcome_to' => 'Velkommen til :web!',
    'your_assets' => 'Se dine assets',
    'your_credentials' => 'Dine Snipe-IT Legitimationsoplysninger',
    'mail_sent' => 'Mail sent successfully!',
];
